#!/usr/bin/env python

import os
from distutils.core import setup
from distutils.log import info
from distutils.command.install_scripts import install_scripts
from tuxtremsplit.application import Application


class InstallScripts(install_scripts):
    """
    Create symbolic link /usr/[local/]bin/txs -> /usr/[local/]bin/tuxtremsplit
    """

    def run(self):
        install_scripts.run(self)
        for file in self.get_outputs():
            txs_path = os.path.dirname(file)
            tuxtremsplit_path = os.path.join(txs_path, "tuxtremsplit")
            if not os.path.exists(tuxtremsplit_path):
                info("creating symbolic link")
                os.symlink(os.path.join(txs_path, "txs"), tuxtremsplit_path)

setup(
    name = Application().settings.name,
    version = Application().settings.version,
    description = Application().settings.description,
    author = Application().settings.author,
    author_email = Application().settings.author_email,
    url = Application().settings.homepage,
    packages = [
        "tuxtremsplit",
        "tuxtremsplit.application",
        "tuxtremsplit.core"],
    scripts = ["txs"],
    data_files = [
        ("share/tuxtremsplit/config", ["config/settings.yml"]),
        ("share/tuxtremsplit/data", ["data/xtm_sfx-1.2.dump"])],
    cmdclass = {'install_scripts': InstallScripts})
