# TuXtremSplit - A Linux Xtremsplit file tool
#
# Copyright (C) 2011 zedtux <zedtux@zedroot.org>
#
# TuXtremSplit is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# TuXtremSplit is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with TuXtremSplit; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
import logging
from tuxtremsplit import TuXtremSplit

from tuxtremsplit.application.settings import Settings
from tuxtremsplit.core.xtmpipe import XtmPipe
from tuxtremsplit.core.action import Action
from tuxtremsplit.core.controller import Controller
from tuxtremsplit.customexceptions import *

class Application(object):
    """ TuXtremSplit Application """
    _instance = None

    def __new__(cls, *args, **kwargs):
        if not cls._instance:
            cls._instance = super(Application, cls).__new__(
                cls, *args, **kwargs
            )
            cls._instance.__settings = Settings()
            cls._instance.__arguments = None
        return cls._instance

    def get_settings(self):
        return self.__settings
    settings = property(get_settings)

    def get_arguments(self):
        return self.__arguments
    def set_arguments(self, arguments):
        self.__arguments = arguments
    arguments = property(get_arguments, set_arguments)

    def start(self, args, options):
        """
        Start TuXtremSplit with user arguments
        """
        # Store arguments in order to access them later
        self.arguments = options

        try:
            # Controller detect/organize/gather files
            controller = Controller(args, options)

            # When Joining
            if Action(controller).is_join():
                TuXtremSplit().logger.debug("Current action is Join")
                # Allowed passing a directory with many groups of XTM files
                for group in controller.identified_groups:
                    # Join XTM files of the current group
                    XtmPipe().merge(group)\
                             .to(controller.destination)

            # When Spliting
            else:
                TuXtremSplit().logger.debug("Current action is Split")
                # Split the source into many XTM files
                XtmPipe().split(controller.source)\
                         .to(controller.destinations)

        # Errors
        except (AlreadyExistingFileError, ArgumentError, \
                IOError, NoEnoughSpaceError, InvalidHeaderError, \
                MD5MismatchError) as error:
            try:
                TuXtremSplit().logger.error(unicode(error))
            except:
                TuXtremSplit().logger.error(error)
        # Infos
        except NoSourceError as error:
            try:
                TuXtremSplit().logger.info(unicode(error))
            except:
                TuXtremSplit().logger.info(error)
