# TuXtremSplit - A Linux Xtremsplit file tool
#
# Copyright (C) 2011 zedtux <zedtux@zedroot.org>
#
# TuXtremSplit is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# TuXtremSplit is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with TuXtremSplit; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
import logging
from tuxtremsplit import TuXtremSplit

import sys
import datetime
import struct
import re

class Tools:
    """ Collection of tools """

    def TDateTime2UnixTimestamp(self, value):
        """ Convert Delphi TDateTime to readable datetime """
        return datetime.datetime.utcfromtimestamp(
            round((value - 25569.0) * 86400.0)
        )

    def is_installed(self):
        """ Return True if the current file is in the System prefix path """
        return __file__.startswith(sys.prefix)

    def hex_string_endian_swap(self, hexa_string):
        """
        Rearranges character-couples in a little endian hex string to
        a big endian hex string and vice-versa.
        'A0B9E340' => '40E3B9A0'
        """
        if len(hexa_string) % 2 != 0:
            return -1

        swapList = []
        for i in range(0, len(hexa_string), 2):
            swapList.insert(0, hexa_string[i:i + 2])

        return "".join(swapList)

    def to_binary(self, hex_string):
        """ Convert hex values to binary """
        ints = [int(hex_string[i:i + 2], 16)
                for i in range(0, len(hex_string), 2)]
        return struct.pack('B' * len(ints), *ints)

    def human_size_to_number(self, human_size):
        """ Convert human readable file size to number """
        match = re.search(r'(\d*\.?\d+)\s?(Bytes?|KB|MB|GB|TB)', human_size)
        if match:
            size, unit = match.group(1), match.group(2)
            try:
                number = int(size)
            except:
                return None
            if unit == "Byte" or unit == "Bytes":
                number = number
            elif unit == "KB":
                number = number * 1024
            elif unit == "MB":
                number = number * 1024 * 1024
            elif unit == "GB":
                number = number * 1024 * 1024 * 1024
            elif unit == "TB":
                number = number * 1024 * 1024 * 1024 * 1024
            return number
        else:
            return None

    def split_len(self, seq, length):
        """ Return given string splitted with given length """
        return [seq[i:i + length] for i in range(0, len(seq), length)]
