# TuXtremSplit - A Linux Xtremsplit file tool
#
# Copyright (C) 2011 zedtux <zedtux@zedroot.org>
#
# TuXtremSplit is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# TuXtremSplit is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with TuXtremSplit; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA

from tuxtremsplit.core.xtmgroup import XtmGroup
from tuxtremsplit.core.xtmpipeworker import XtmPipeWorker

class XtmPipe(object):
    """
    XTM Pipe
    
    Main pipe splitting or joining a source to a destination.
    This is the core and the base of the application.
    """

    def __init__(self):
        """ Constructor """
        self.__current_source = None

    def merge(self, group):
        """ Used when the XtmPipe have to join XTM files """
        self.__current_source = group
        return self

    def split(self, source):
        """ Used when the XtmPipe have to split a file into XTM files """
        self.__current_source = source
        return self

    def to(self, target):
        """
        Method used for both cases to define the output path of the XtmPipe
        and to engage the XtmPipe
        """
        xtm_pipe_worker = XtmPipeWorker()
        # Inputs
        xtm_pipe_worker.enqueue(self.__current_source).as_input()
        # Check destination free space
        if isinstance(target, XtmGroup):
            target.check_destination_free_space()
        else:
            self.__current_source.check_destination_free_space()
        # Outputs
        xtm_pipe_worker.enqueue(target).as_output()
        # Let's go!
        xtm_pipe_worker.start()
